;; Copyright (c) 2006, Philippe Ivaldi.
;; Version: $Id: pi-resize-frames.el,v 0.0 2006/12/02 18:52:12 Philippe Ivaldi Exp $

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
;; 02110-1301, USA.

;; Commentary:
;; Features to resize easily the frames.
;; "C-x <up>" resize frame up and arrows to adjust.
;; "C-x <down>" resize frame down and arrows to adjust.
;; "C-x <right>" resize frame right and arrows to adjust.
;; "C-x <left>" resize frame left and arrows to adjust.
;; Press C-x <one_arrow> to finish

;; INSTALLATION:
;; Put this code in your .emacs:
;; (require 'pi-resize-frames)

;;; Code:

(defvar pi-resize-frame-message "Press C-x <one_arrow> to finish.")
(defvar pi-resize-backup-keys)

(defun pi-resize-frames-set-key ()
  (setq pi-resize-backup-keys (mapcar #'(lambda (KEY)
                                          (global-key-binding KEY))
                                      '([up] [down] [left] [right] " ")))
  (pi-resize-frames-erase)
  (define-key (current-global-map) (kbd "<up>")
    (lambda () 
      (interactive)
      (shrink-window 1)
      (message pi-resize-frame-message)))
  (define-key (current-global-map) (kbd "<down>")
    (lambda () 
      (interactive)
      (shrink-window -1)
      (message pi-resize-frame-message)))
  (define-key (current-global-map) (kbd "<left>")
    (lambda ()
      (interactive)
      (shrink-window-horizontally 1)
      (message pi-resize-frame-message)))
  (define-key global-map (kbd "<right>")
    (lambda ()
      (interactive)
      (shrink-window-horizontally -1)
      (message pi-resize-frame-message)))
  (message pi-resize-frame-message))

(defun pi-resize-frames-unset-keys ()
  (interactive)
  (let ((keyl '([up] [down] [left] [right] " ")))
    (dolist (x '(0 1 2 3 4) nil)
      (define-key (current-global-map) (nth x keyl) (nth x pi-resize-backup-keys))))
  (pi-resize-frames-init))

;;;###autoload
(defun pi-resize-frames-up ()
  (interactive)
  (pi-resize-frames-set-key)
  (shrink-window 1))
;;;###autoload
(defun pi-resize-frames-down ()
  (interactive)
  (pi-resize-frames-set-key)
  (shrink-window -1))
;;;###autoload
(defun pi-resize-frames-left ()
  (interactive)
  (pi-resize-frames-set-key)
  (shrink-window-horizontally))
;;;###autoload
(defun pi-resize-frames-right ()
  (interactive)
  (pi-resize-frames-set-key)
  (shrink-window-horizontally -1))

(defun pi-resize-frames-erase ()
  (global-set-key (kbd "C-x <up>") 'pi-resize-frames-unset-keys)
  (global-set-key (kbd "C-x <down>") 'pi-resize-frames-unset-keys)
  (global-set-key (kbd "C-x <right>") 'pi-resize-frames-unset-keys)
  (global-set-key (kbd "C-x <left>") 'pi-resize-frames-unset-keys))

(defun pi-resize-frames-init ()
  (global-set-key (kbd "C-x <up>") 'pi-resize-frames-up)
  (global-set-key (kbd "C-x <down>") 'pi-resize-frames-down)
  (global-set-key (kbd "C-x <right>") 'pi-resize-frames-right)
  (global-set-key (kbd "C-x <left>") 'pi-resize-frames-left))

;;;###autoload
(global-set-key (kbd "C-x <up>") 'pi-resize-frames-up)
;;;###autoload
(global-set-key (kbd "C-x <down>") 'pi-resize-frames-down)
;;;###autoload
(global-set-key (kbd "C-x <right>") 'pi-resize-frames-right)
;;;###autoload
(global-set-key (kbd "C-x <left>") 'pi-resize-frames-left)

(provide 'pi-resize-frames)
;;; pi-resize-frames.el ends here
