;;: -*- emacs-lisp -*-
;;; pi-tempo-abbrev-latex.el
;;; Author: Philippe Ivaldi
;;; Last modified: Sun Jul  1 01:02:00 CEST 2007

(require 'pi-tempo-abbrev)

;; *=======================================================*
;; *.............Abbreviations for LaTeX-mode..............*
;; *=======================================================*

(eval-after-load "latex" ;; Eval this code only when Auctex is provided
  '(progn
     (tempo-abbrev-add
      '(LaTeX-mode-hook) ;; List of modes where the following table will use.
      'tempo-abbrev-latex-table    ;; Table name (* MUST BE UNIQUE *).
      'tempo-abbrev-latex-tagslist ;; Name of the variable where the tag list should be added.
      '(("int"  ("\\int_{" (p "Borne inf: ") "}^{" (p "Borne sup: ") "}" p 
                 "\\;d"(p "variable: ")))
        ("abs" ("\\left\\vert "p" \\right\\vert"p))
        ("norm" ("\\left\\Vert\\vec{"p"}\\right\\Vert"p))
        ("df" ("\\dfrac{"p"}{"p"}"p))
        ("nbr" ("nombre"))
        ("nbrc" ("nombre"p" complexe"p))
        ("nbrr" ("nombre"p" rel"p))
        ("bi" ("\\binom{"p"}{"p"}"p))
        ("fr" ("\\frac{"p"}{"p"}"p))
        ("sq" ("\\sqrt{"p"}"p))
        ("sqn" ("\\sqrt["p"]{"p"}"p))
        ("coo" ("\\left("p"\\,;\\,"p"\\right)"p))
        ("coop" ("\\left["p"\\,;\\,"p"\\right]"p))
        ("coov" (& >"\\left(\\begin{array}[c]{c}%"n
                   r >
                   n"\\end{array}\\right)"> %))
        ("par" ("\\left("p"\\right)"p))
        ("cro" ("\\left["p"\\right]"p))
        ("acc" ("\\left\\{"p"\\right\\}"p))
        ("av" ("\\left(\\vec{"p"}\\,;\\,\\vec{"p"}\\right)"p))
        ("se" ("\\set{"p"}"p))
        ("ov" ("\\overline{"p"}"p))
        ("und" ("\\underline{"p"}"p))
        ("db" ("\\dbinom{"p"}{"p"}"p))
        ("te" ("\\text{"p"}"p))
        ("ve" ("\\vecteur{"p"}"p))
        ("mq" ("montrer que"))
        ("dmq" ("dmontrer que"))
        ("Mq" ("Montrer que"))
        ("Dmq" ("Dmontrer que"))
        ("cr" ("courbe reprsentative"))
        ("Et" ("\\'Etudier"))
        ("oij" ("(O\\,;\\,\\vec{\\imath},\\vec{\\jmath})"))
        ("ouv" ("(O\\,;\\,\\vec{u},\\vec{v})"))
        ("oijk" ("(O\\,;\\,\\vec{\\imath},\\vec{\\jmath},\\vec{k})"))
        ("got" ("\\textgoth{"p"}"p))
        ("fra" ("\\textfrak{"p"}"p))
        ("ssi" ("si, et seulement si, "))
        ("rp"  ("repre orthonorm "))
        ("act" ((act)))
        ("lv"  ((f TeX-insert-macro "limv")))
        ("ca"  ((f TeX-insert-macro "card")))
        ("fr"  ("\\frac{"p"}{"p"}"p)) 
        ("iff" ("\\left["p"\\,;\\,"p"\\right]"p))
        ("ifo" ("\\left["p"\\,;\\,"p"\\right["p))
        ("iof" ("\\left]"p"\\,;\\,"p"\\right]"p))
        ("ioo" ("\\left]"p"\\,;\\,"p"\\right["p))
        ("Df"  ("\\mathscr{D}_{f}"))
        ("Cf"  ("\\mathscr{C}_{f}"))
        ("tgt"  ("\\mathscr{T}_{"p"}"))
        ("cal"  ("\\mathscr{"p"}"p))
        ("ent"  ("\\Rightarrow "))
        ("equ" ("\\Leftrightarrow "))
        ("nent"  ("\\nRightarrow "))
        ("nequ" ("\\nLeftrightarrow "))
        ("gui"  ("\\og{}"p"\\fg{}"p))
        ("nn"  ("\\mathbb{N}"))
        ("nne"  ("\\mathbb{N}^{\\star}"))
        ("rr"  ("\\mathbb{R}"))
        ("rre"  ("\\mathbb{R}^{\\star}"))
        ("rrp"  ("\\mathbb{R}^{+}"))
        ("rrm"  ("\\mathbb{R}^{-}"))
        ("rrep"  ("\\mathbb{R}^{\\star+}"))
        ("rrem"  ("\\mathbb{R}^{\\star-}"))
        ("cc"  ("\\mathbb{C}"))
        ("cce"  ("\\mathbb{C}^\\star"))
        ("dd"  ("\\mathbb{D}"))
        ("pp"  ("\\mathscr{P}"))
        ("zz"  ("\\mathbb{Z}"))
        ("dd"  ("\\mathbb{D}"))
        ("qq"  ("\\mathbb{Q}"))
        ("eto"  ("^{\\star}"))
        ("etop"  ("^{\\star+}"))
        ("etom"  ("^{\\star-}"))
        ("qpq"  ("\\quad;\\quad"))
        ("qeq"  ("\\quad\\text{et}\\quad"))
        ("qoq"  ("\\quad\\text{o"p"}\\quad"))
        ("qpq"  ("\\quad;\\quad"))
        ("mpv"  ("\\,;\\,"))
        ("comp" ("\\makebox["(p "longueur (en mm):")"mm][l]{\\dotfill}\\;"))
        ("limx" ("\\underset{x\\rightarrow{}"p"}{\\lim}"p))
        ("limn" ("\\underset{n\\rightarrow+\\infty}{\\lim}"))
        ("lim" ("\\underset{"(p "Variable : ")"\\rightarrow{}"p"}{\\lim}"p))
        ("limxo" ("\\underset{x\\rightarrow0}{\\lim}"p))
        ("lims" ("\\underset{"(p "Variable : ")"\\stackrel{>}{\\rightarrow}"p"}{\\lim}"p))
        ("limi" ("\\underset{"(p "Variable : ")"\\stackrel{<}{\\rightarrow}"p"}{\\lim}"p))
        ("ten" ("\\xrightarrow[]{\\,"(p "Variable : ")"\\longrightarrow"p"\\,}"p))
        ("vs" ("\\vspace*{"(p "Longueur en mm: ")"mm}"))
        ("hs" ("\\hspace*{0mm}"))
        ("hf" ("\\hfill"))
        ("hfs" ("\\hfill\\hspace*{0mm}"))
        ("hsf" ("\\hspace*{0mm}\\hfill"))
        ("ct" ("\\cos\\theta"))
        ("st" ("\\sin\\theta"))
        ("ca" ("\\cos\\alpha"))
        ("sa" ("\\sin\\alpha"))
        ("sol" ("\\mathscr{S}=\\left\\{"p"\\right\\}"p))
        ("sol2" ("\\mathscr{S}=\\left\\{"p"\\,;\\,"p"\\right\\}"p))
        ("sol3" ("\\mathscr{S}=\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("sol4" ("\\mathscr{S}=\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("sol5" ("\\mathscr{S}=\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("ens" ("\\left\\{"p"\\right\\}"p))
        ("ens2" ("\\left\\{"p"\\,;\\,"p"\\right\\}"p))
        ("ens3" ("\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("ens4" ("\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("ens5" ("\\left\\{"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\,;\\,"p"\\right\\}"p))
        ("vec"  ("\\vec{"r"}"p))
        ("aor"  ("\\left(\\vec{"r"}\\,,\\;\\vec{"r"}\\right)"p))
        ("aori"  ("\\left(\\vec{\\imath}\\,,\\;\\vec{"r"}\\right)"p))
        ("aoru"  ("\\left(\\vec{u}\\,,\\;\\vec{"r"}\\right)"p))
        ("pis"  ("\\frac{"(p "n.pi/q, n= ")"\\pi}{"(p "n.pi/q, q= ")"}"p))
        ("dpis"  ("\\dfrac{"(p "n.pi/q, n= ")"\\pi}{"(p "n.pi/q, q= ")"}"p))
        ("pinf"  ("+\\infty"))
        ("minf"  ("-\\infty"))
        ("sca"  ("\\vec{"p"}\\cdot\\vec{"p"}"p))
        ("tx"  ("\\text{"p"}"p))
        ("arg"  ("\\arg{"p"}"p))
        ("ass" ("\\longmapsto{}"))
        ("dp"  ("\\["p"\\]"))
        ("mod"  ("\\mod{2\\pi}"))
        ("ei"  ("\\e^{i"p"}"p))
        ("eipis"  ("\\e^{i\\frac{\pi}{"p"}"p))
        ("eia"  ("\\e^{i\\alpha}"))
        ("eib"  ("\\e^{i\\beta}"))
        ("eit"  ("\\e^{i\\theta}"))
        ("reia"  ("r\\e^{i\\alpha}"))
        ("reib"  ("r\\e^{i\\beta}"))
        ("reit"  ("r\\e^{i\\theta}"))
        ("colo"  ("\\colorize<"p">"p))
        ("coloi"  ("\\colorizeimp<"p">"p))
        ("colod"  ("\\colorizedef<"p">"p))
        ("som"  ("\\sum\\limits_{"p"}^{"p"}"))
        ("dis"  ("\\displaystyle"p))
        ("txt" ("\\text{"p"}"p))
        ("ince" ("\\subseteq{}"))
        ("inc" ("\\subset{}"))
        ("line" ("\\renewcommand{\\baselinestretch}{1.5}\\small\\normalsize"))
        ("enu" ((f LaTeX-env-item "enumerate")))
        ("ite" ((f LaTeX-env-item "itemize")))
        ("des" ((f LaTeX-env-item "description")))
        ("arr"  ((f LaTeX-environment-menu "array")))
        ("fig"  ((f LaTeX-environment-menu "figure")))
        ("pic" ((f LaTeX-environment-menu "picture")))
        ("eque" ((f LaTeX-environment-menu "equation")))
        ("rem" ((f LaTeX-environment-menu "remark")))
        ("the" ((f LaTeX-environment-menu "theorem")))
        ("pro" ((f LaTeX-environment-menu "proposition")))
        ("def" ((f LaTeX-environment-menu "definition")))
        ("cor" ((f LaTeX-environment-menu "corollary")))
        ("exe" ((f LaTeX-environment-menu "exercise")))
        ("exep" ((f LaTeX-environment-menu "example")))
        ("cla" ((f LaTeX-environment-menu "claim")))
        ("tab" ((f LaTeX-environment-menu "tabular")))
        ("cen" ((f LaTeX-environment-menu "center")))
        ("eqn" ((f LaTeX-environment-menu "eqnarray*")))
        ("mini" ((f LaTeX-environment-menu "minipage")))
        ("upk" ((f TeX-insert-macro "usepackage")))
        ("newc" ((f TeX-insert-macro "newcommand")))
        ("rnewc" ((f TeX-insert-macro "renewcommand")))
        ("newce" ((f TeX-insert-macro "newcommand*")))
        ("newv" ((f TeX-insert-macro "newenvironment")))
        ("rnewv" ((f TeX-insert-macro "renewenvironment")))
        ("lab" ((f TeX-insert-macro "label")))
        ("ref" ((f TeX-insert-macro "ref")))
        ("pref" ((f TeX-insert-macro "pageref")))
        ("mul" (& > "\\begin{multicols}{"(p "Nbre de cols :")"}%"n>
                  r >
                  n> "\\end{multicols}"> %))
        ("bmini"  "boxedminipage" (& >"\\begin{boxedminipage}["(p "Position :")"]{"(p "Largeur :")"}"n>
                                     r >
                                     n> "\\end{boxedminipage}"> %))
        ;; `Place_here_your_abbreviations_for_LaTeX-mode'
        ))))
